==========================
Ninja Python Distributions
==========================

.. image:: https://ci.appveyor.com/api/projects/status/cvgsgfo2rsyq2ej8/branch/master?svg=true
    :target: https://ci.appveyor.com/project/scikit-build/ninja-python-distributions/branch/master

.. image:: https://circleci.com/gh/scikit-build/ninja-python-distributions.svg?style=svg
    :target: https://circleci.com/gh/scikit-build/ninja-python-distributions

.. image:: https://travis-ci.org/scikit-build/ninja-python-distributions.svg?branch=master
    :target: https://travis-ci.org/scikit-build/ninja-python-distributions

`Ninja <http://www.ninja-build.org>`_ is a small build system with a focus on speed.

The Ninja python wheels provide `ninja 1.7.2 <https://ninja-build.org/manual.html>`_ executable
and `ninja_syntax.py` for generating .ninja files.

.. image:: https://raw.githubusercontent.com/scikit-build/ninja-python-distributions/master/ninja-python-distributions-logo.png

This project is maintained by Jean-Christophe Fillion-Robin from Kitware Inc.
It is covered by the `Apache License, Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0>`_.

Ninja is also distributed under the `Apache License, Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0>`_.
For more information about Ninja, visit https://ninja-build.org

* Documentation: https://github.com/scikit-build/ninja-python-distributions#readme
* Source code: https://github.com/scikit-build/ninja-python-distributions
* Mailing list: https://groups.google.com/forum/#!forum/scikit-build

Logo was originally created by Libby Rose from Kitware Inc.
It is covered by `CC BY 4.0 <https://creativecommons.org/licenses/by/4.0/>`_.
